Ocyan plugin Hotel Widget
=========================
Installation
-------------
Add `ocyan.plugin.hotelwidget` to your projects dependencies.

Describe how to install the plugin. 


About & Usage of Hotel Widget
-----------------------------
Hotel Widget

Describe how to use the plugin.


Configuration
-------------
Settings you need to configure in config.json
* Option
    * Description
* Option
    * Description
* Option
    * Description


Example: 

```json

```